#!/usr/bin/env python

from math import *
from novas import *

#deltat = 67.0
deltat = 64.198

JD = Cal2JD(2001,6,21,0.0)
tjd = JD + deltat / 86400.0

print "Almanac entries for: %d %d %d %4.2f" % JD2Cal(JD)
print "JD = ",JD, " tjd = ", tjd

# Moon
moon = Body()
moon.type = 0
moon.number = 11
moon.name = "Moon"

# Sun
sun = Body()
sun.type = 0
sun.number = 10
sun.name = "Sun"

# Earth
e = Body()
e.type = 0
e.number = 3

# from degree to (degree ,min)
def d_to_dm(a):
   if a < 0.0:
      neg = 1
   else:
      neg = 0

   a = abs(a)
   deg = int(a)
   a = a - deg
   m = a * 60.0

   if neg:
      if deg > 0:
          deg = -deg
      else: 
          m = -m
   return deg, m

# degree to degree within range 0..360
def mod360(a):
    a = fmod(a, 360.0)
    if a < 0.0:
        a = a + 360.0
    return a

# SiderealTime needs argument ee (equation of equinox) to calculate
# apparent sidereal time (ee = 0.0 returns mean sidereal time)
# ee is calculated with EarthTilt a low level novas function

def eq_of_equinox(tjd):
   out = EarthTilt(tjd)
   ee = out[2]
   return ee

   
header = """UT   GHA         Decl       Semi-Di   GHA         Decl       Semi-Di
     Moon                             Sun
"""

# AppPlanet returns a tuple (status, RA (h), Decl (deg), Dist (AU))

def format(obj):
    ee = eq_of_equinox(tjd)
    ast = SiderealTime(floor(JD), JD - floor(JD), ee)
    o = AppPlanet(tjd, obj, e)
    sha = 360.0 - o[1]*15.0
    eadst = (0.0 + o[3]) * KMAU
    gha = mod360(sha + 360 * ast / 24.0)
    GHA_s = "%3d %5.2f  " % d_to_dm(gha)
    Decl_s = "%3d %5.2f  " % d_to_dm(o[2])
    if obj.number == 11:
        radius = 1737.4
    else:
        radius = 695500.0
    sd_s =  "%2d %5.2f  " % d_to_dm(180 * atan(radius/eadst)/ pi)
    s =  GHA_s + Decl_s + sd_s
    return s


print header
for i in range(25):
    print "%02i  " % i,
    print format(moon), format(sun)
    tjd += (1.0 / 24.0)
    JD += (1.0 / 24.0)
