#include <stdio.h>
#include <stdlib.h>
#include "novas.h"

char * h2s(char buf[], double hour);
char * d2s(char buf[], double deg);

int main (void)
{

   short int error = 0;
   short int i, j;
   char buf1[256];
   char buf2[256];

/*
   'deltat' is te difference in time scales, TT - UT1.
   2001.5 : deltat = 64.198  (source IERS)

*/

/*
   in a private communication Mr Kaplan stated that MICA
   uses an estimation of deltat equal to 67 s for 2001.5
   So for comparision we set:
*/

   double deltat = 67.0;
/*
   tjd in TT
   20010621
   eclipse of the SUN in Africa
*/

   double tjd = 2452081.5  + deltat / 86400.0;
   double ra, dec, dis;


/*
   Te observer's terrestrial coordinates (latitude, longitude, height).
   Lusaka
*/

   site_info geo_loc = {-15.3333333333333333, 28.3333333333333333, 0.0, 20.0, 1010.0};

/*
   Structures containing te body designation for Earth, Moon & Sun.
*/

   body earth;
   body moon;
   body sun;

/*
   Set up the structure containing the body designation for Earth, etc.
*/

   if (error = set_body (0,3,"Earth", &earth))
   {
      printf ("Error %d from set_body.\n", error);
      exit (1);
   }
   if (error = set_body (0,11,"Moon", &moon))
   {
      printf ("Error %d from set_body.\n", error);
      exit (1);
   }
   if (error = set_body (0,10,"Sun", &sun))
   {
      printf ("Error %d from set_body.\n", error);
      exit (1);
   }

/*
   print results for 24 hours
*/
   printf("Moon and Sun positions at Lusaka 20010621\n\n");

   for(i=0;i<25;i++)
   {
       printf("%2i:00:00.0 ",i);
       topo_planet(tjd, &moon, &earth, deltat,&geo_loc, &ra, &dec, &dis);
       printf ("%12s   %12s   %12.3f   ", h2s(buf1, ra), d2s(buf2, dec), dis * KMAU);
       topo_planet(tjd, &sun, &earth, deltat,& geo_loc, &ra, &dec, &dis);
       printf ("%12s   %12s   %12.9f  \n", h2s(buf1, ra), d2s(buf2, dec), dis);
       tjd = tjd+1.0/24.0;
   }
   exit (0);
}

char * h2s(char buf[], double hour)
{
	int h, min;
	double sec;
        char *p;

	p = buf;
	h = (int) floor(hour);
	
	min = (int) floor(hour*60 - 60.0*h);
	sec = hour*3600.0  - h*3600.0 - 60.0*min;
	sprintf(buf, "%2i %2i %6.3f", h, min, sec);
	return p;
}

char * d2s(char buf[], double deg)
{
	int d, min;
	double sec;
        char *p;

	p = buf;
	d = (int) floor(deg);
	
	min = (int) floor(deg*60 - 60.0*d);
	sec = deg*3600.0  - d*3600.0 - 60.0*min;
	sprintf(buf, "%2i %2i %6.2f", d, min, sec);
	return p;
}
