%module novas

%{
#include "novas.h"
%}


%include typemaps.i

%typemap (memberin) char [ANY] {
	strncpy($target, $source, $dim0);
}

%include "novascon.h"

/*
   Structures.
*/

/*
   struct body: designates a celestial object.

   type              = type of body
                     = 0 ... major planet, Sun, or Moon
                     = 1 ... minor planet
   number            = body number
                       For 'type' = 0: Mercury = 1, ..., Pluto = 9,
                                       Sun = 10, Moon = 11
                       For 'type' = 1: minor planet number
   name              = name of the body (limited to 99 characters)
*/

%name (Body) typedef struct {
	body();
	~body();
%name (type)	short int type;
%name (number)	short int number;
%name (name)	char name[100];

} body;

/*
   struct site_info: data for the observer's location.  The atmospheric 
                     parameters are used only by the refraction 
                     function called from function 'equ_to_hor'.
                     Additional parameters can be added to this 
                     structure if a more sophisticated refraction model 
                     is employed.
                     
   latitude           = geodetic latitude in degrees; north positive.
   longitude          = geodetic longitude in degrees; east positive.
   height             = height of the observer in meters.
   temperature        = temperature (degrees Celsius).
   pressure           = atmospheric pressure (millibars)
*/

%name (Location) typedef struct {
      site_info();
      ~site_info();
%name (lat)  double latitude;
%name (lon)  double longitude;
%name (h)    double height;
%name (temp) double temperature;
%name (pres) double pressure;
} site_info;

/*
   struct cat_entry: the astrometric catalog data for a star; equator 
                     and equinox and units will depend on the catalog.
                     While this structure can be used as a generic
                     container for catalog data, all high-level 
                     NOVAS-C functions require J2000.0 catalog data 
                     with FK5-type units (shown in square brackets
                     below).
                     
   catalog[4]         = 3-character catalog designator.
   starname[51]       = name of star.
   starnumber         = integer identifier assigned to star.
   ra                 = mean right ascension [hours].
   dec                = mean declination [degrees].
   promora            = proper motion in RA [seconds of time per 
                        century].
   promodec           = proper motion in declination [arcseconds per 
                        century].
   parallax           = parallax [arcseconds].
   radialvelocity     = radial velocity [kilometers per second].
*/

%name (Cat) typedef struct {
      cat_entry();
      ~cat_entry();

      char catalog[4];
      char starname[51];
      long int starnumber;
      double ra;
      double dec;
      double promora;
      double promodec;
      double parallax;
      double radialvelocity;
} cat_entry;

/*
   Function prototypes
*/

%name (AppStar) app_star (double tjd, body *earth, cat_entry *star,
			double *OUTPUT, double *OUTPUT);

%name (AppPlanet) app_planet (double tjd, body *ss_object, body *earth, 
                         double *OUTPUT, double *OUTPUT, double *OUTPUT);

%name (TopoStar) topo_star (double tjd, body *earth, double deltat,
                        cat_entry *star, site_info *location, 
                        double *OUTPUT, double *OUTPUT);

%name (TopoPlanet)   topo_planet (double tjd, body *ss_object, body *earth,
                          double deltat, site_info *location, 

                          double *OUTPUT, double *OUTPUT, double *OUTPUT);
%name (VirtualStar)  virtual_star (double tjd, body *earth, cat_entry *star,
                           double *OUTPUT, double *OUTPUT);

%name (VirtualPlanet)  virtual_planet (double tjd, body *ss_object, body *earth,
                             double *OUTPUT, double *OUTPUT, double *OUTPUT);

%name (LocalStar)  local_star (double tjd, body *earth, double deltat,
                         cat_entry *star, site_info *location,
                         double *OUTPUT, double *OUTPUT);

%name (LocalPlanet) local_planet (double tjd, body *ss_object, body *earth,
                           double deltat, site_info *location,
                           double *OUTPUT, double *OUTPUT, double *OUTPUT);

%name (AstroStar) astro_star (double tjd, body *earth, cat_entry *star,
                         double *OUTPUT, double *OUTPUT);

%name (AstroPlanet) astro_planet (double tjd, body *ss_object, body *earth,
                           double *OUTPUT, double *OUTPUT, double *OUTPUT);

%name (MeanStar)  mean_star (double tjd, body *earth, double ra, double dec,
                        double *OUTPUT, double *OUTPUT);

%name (SiderealTime) void sidereal_time (double julianhi, double julianlo, double ee,
                       double *OUTPUT);

%name (Equ2Hor)  void equ2hor (double tjd, double deltat, double x, double y, 
                 site_info *location, double ra, double dec, 
                 short int ref_option,
                 double *OUTPUT, double *OUTPUT, double *OUTPUT, double *OUTPUT);

%name (Cal2JD)  double julian_date (short int year, short int month, short int day,
                       double hour);

%name (JD2Cal)  void cal_date (double tjd,
                  short int *OUTPUT, short int *OUTPUT, short int *OUTPUT,
                  double *OUTPUT);

%name (EarthTilt) void earthtilt (double tjd,
		double *OUTPUT, double *OUTPUT, double *OUTPUT, double *OUTPUT, double *OUTPUT);
